summaryrefslogtreecommitdiff
path: root/gui
diff options
context:
space:
mode:
authorSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
committerSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
commit5f868fa161d5827e45a060a0b17b44a997625315 (patch)
tree1694ae3dfcb0189abdf098edbf6dae0bf2a18e4d /gui
parentc7eb23ccf1813fb4ca47c309c40baff308151237 (diff)
downloadpcsxr-5f868fa161d5827e45a060a0b17b44a997625315.tar.gz
Rebranding.
git-svn-id: https://pcsxr.svn.codeplex.com/svn/pcsxr@67621 e17a0e51-4ae3-4d35-97c3-1a29b211df97
Diffstat (limited to 'gui')
-rw-r--r--gui/Cheat.c8
-rw-r--r--gui/ConfDlg.c10
-rw-r--r--gui/Config.c4
-rw-r--r--gui/DebugMemory.c2
-rw-r--r--gui/Gtk2Gui.c12
-rw-r--r--gui/Linux.h20
-rw-r--r--gui/LnxMain.c30
-rw-r--r--gui/Makefile.am18
-rw-r--r--gui/MemcardDlg.c6
-rw-r--r--gui/Plugin.c6
10 files changed, 62 insertions, 54 deletions
diff --git a/gui/Cheat.c b/gui/Cheat.c
index 3848e9f2..89e2c0fa 100644
--- a/gui/Cheat.c
+++ b/gui/Cheat.c
@@ -313,7 +313,7 @@ static void OnCheatListDlg_OpenClicked(GtkWidget *widget, gpointer user_data) {
filter = gtk_file_filter_new ();
gtk_file_filter_add_pattern (filter, "*.cht");
- gtk_file_filter_set_name (filter, _("PCSX Cheat Code Files (*.cht)"));
+ gtk_file_filter_set_name (filter, _("PCSXR Cheat Code Files (*.cht)"));
gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), filter);
filter = gtk_file_filter_new ();
@@ -353,7 +353,7 @@ static void OnCheatListDlg_SaveClicked(GtkWidget *widget, gpointer user_data) {
filter = gtk_file_filter_new();
gtk_file_filter_add_pattern(filter, "*.cht");
- gtk_file_filter_set_name(filter, _("PCSX Cheat Code Files (*.cht)"));
+ gtk_file_filter_set_name(filter, _("PCSXR Cheat Code Files (*.cht)"));
gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), filter);
filter = gtk_file_filter_new();
@@ -389,7 +389,7 @@ void RunCheatListDialog() {
GtkTreeViewColumn *column;
GtkCellRenderer *renderer;
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "CheatListDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "CheatListDlg", NULL);
if (!xml) {
g_warning(_("Error: Glade interface could not be loaded!"));
return;
@@ -1119,7 +1119,7 @@ void RunCheatSearchDialog() {
GtkTreeSelection *treesel;
GtkTreeViewColumn *column;
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "CheatSearchDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "CheatSearchDlg", NULL);
if (!xml) {
g_warning(_("Error: Glade interface could not be loaded!"));
return;
diff --git a/gui/DebugMemory.c b/gui/DebugMemory.c
index bbce1f17..d9437a9a 100644
--- a/gui/DebugMemory.c
+++ b/gui/DebugMemory.c
@@ -254,7 +254,7 @@ void RunDebugMemoryDialog() {
PangoFontDescription *pfd;
int i;
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "MemViewDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "MemViewDlg", NULL);
if (!xml) {
g_warning(_("Error: Glade interface could not be loaded!"));
return;
diff --git a/gui/Linux.h b/gui/Linux.h
index 29620b45..352a0f72 100644
--- a/gui/Linux.h
+++ b/gui/Linux.h
@@ -26,16 +26,16 @@
#include "Cheat.h"
-#define DEFAULT_MEM_CARD_1 "/.pcsx/memcards/card1.mcd"
-#define DEFAULT_MEM_CARD_2 "/.pcsx/memcards/card2.mcd"
-#define MEMCARD_DIR "/.pcsx/memcards/"
-#define PLUGINS_DIR "/.pcsx/plugins/"
-#define PLUGINS_CFG_DIR "/.pcsx/plugins/cfg/"
-#define PCSX_DOT_DIR "/.pcsx/"
-#define BIOS_DIR "/.pcsx/bios/"
-#define STATES_DIR "/.pcsx/sstates/"
-#define CHEATS_DIR "/.pcsx/cheats/"
-#define PATCHES_DIR "/.pcsx/patches/"
+#define DEFAULT_MEM_CARD_1 "/.pcsxr/memcards/card1.mcd"
+#define DEFAULT_MEM_CARD_2 "/.pcsxr/memcards/card2.mcd"
+#define MEMCARD_DIR "/.pcsxr/memcards/"
+#define PLUGINS_DIR "/.pcsxr/plugins/"
+#define PLUGINS_CFG_DIR "/.pcsxr/plugins/cfg/"
+#define PCSXR_DOT_DIR "/.pcsxr/"
+#define BIOS_DIR "/.pcsxr/bios/"
+#define STATES_DIR "/.pcsxr/sstates/"
+#define CHEATS_DIR "/.pcsxr/cheats/"
+#define PATCHES_DIR "/.pcsxr/patches/"
extern gboolean UseGui;
extern int StatesC;
diff --git a/gui/Makefile.am b/gui/Makefile.am
index db3daa3f..17ef8927 100644
--- a/gui/Makefile.am
+++ b/gui/Makefile.am
@@ -1,4 +1,4 @@
-AM_CPPFLAGS = -DPACKAGE_DATA_DIR=\"${datadir}/pcsx/\" \
+AM_CPPFLAGS = -DPACKAGE_DATA_DIR=\"${datadir}/pcsxr/\" \
-DPIXMAPDIR=\"${datadir}/pixmaps/\" \
-DLOCALE_DIR=\"${datadir}/locale/\" \
$(GTK2_CFLAGS) $(GLADE2_CFLAGS) \
@@ -6,19 +6,27 @@ AM_CPPFLAGS = -DPACKAGE_DATA_DIR=\"${datadir}/pcsx/\" \
-DPSEMU_DATA_DIR=\"${datadir}/psemu\" \
-DDEF_PLUGIN_DIR=\"${libdir}/games/psemu\"
-bin_PROGRAMS = pcsx
+bin_PROGRAMS = pcsxr
-pcsx_SOURCES = \
+pcsxr_SOURCES = \
LnxMain.c \
+ Linux.h \
+ nopic.h \
Plugin.c \
Config.c \
Gtk2Gui.c \
MemcardDlg.c \
+ MemcardDlg.h \
ConfDlg.c \
+ ConfDlg.h \
Cheat.c \
+ Cheat.h \
DebugMemory.c \
- AboutDlg.c
+ DebugMemory.h \
+ AboutDlg.c \
+ AboutDlg.h \
+ gdk-compat.h
-pcsx_LDADD = \
+pcsxr_LDADD = \
../libpcsxcore/libpcsxcore.a \
$(GTK2_LIBS) $(GLADE2_LIBS) -lpthread -lz -lm -lXext -lXtst
diff --git a/gui/Plugin.c b/gui/Plugin.c
index 74c71051..42d9b1d9 100644
--- a/gui/Plugin.c
+++ b/gui/Plugin.c
@@ -324,7 +324,7 @@ int _OpenPlugins() {
ret = SPU_open();
if (ret < 0) { SysMessage(_("Error opening SPU plugin!")); return -1; }
SPU_registerCallback(SPUirq);
- ret = GPU_open(&gpuDisp, "PCSX", NULL);
+ ret = GPU_open(&gpuDisp, "PCSXR", NULL);
if (ret < 0) { SysMessage(_("Error opening GPU plugin!")); return -1; }
GPU_registerCallback(GPUbusy);
ret = PAD1_open(&gpuDisp);
@@ -342,9 +342,9 @@ int _OpenPlugins() {
char dotdir[MAXPATHLEN];
strncpy(dotdir, getenv("HOME"), MAXPATHLEN-100);
- strcat(dotdir, "/.pcsx/plugins/");
+ strcat(dotdir, "/.pcsxr/plugins/");
- strcpy(info.EmuName, "PCSX " PACKAGE_VERSION);
+ strcpy(info.EmuName, "PCSXR " PACKAGE_VERSION);
strncpy(info.CdromID, CdromId, 9);
strncpy(info.CdromLabel, CdromLabel, 9);
info.psxMem = psxM;
diff --git a/gui/ConfDlg.c b/gui/ConfDlg.c
index 533159b2..b4265fd2 100644
--- a/gui/ConfDlg.c
+++ b/gui/ConfDlg.c
@@ -98,7 +98,7 @@ void ConfigurePlugins() {
UpdatePluginsBIOS();
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "ConfDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "ConfDlg", NULL);
if (!xml) {
g_warning(_("Error: Glade interface could not be loaded!"));
@@ -109,7 +109,7 @@ void ConfigurePlugins() {
ConfDlg = glade_xml_get_widget(xml, "ConfDlg");
- gtk_window_set_title(GTK_WINDOW(ConfDlg), _("Configure PCSX"));
+ gtk_window_set_title(GTK_WINDOW(ConfDlg), _("Configure PCSXR"));
/* Set the paths in the file choosers to be based on the saved configurations */
widget = glade_xml_get_widget(xml, "GtkFileChooser_Bios");
@@ -194,7 +194,7 @@ void OnConf_Net() {
return;
}
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "NetDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "NetDlg", NULL);
if (!xml) {
g_warning(_("Error: Glade interface could not be loaded!"));
@@ -671,7 +671,7 @@ void UpdatePluginsBIOS() {
scan_bios_dir(Config.BiosDir);
// The BIOS list always contains the PCSX internal BIOS
add_bios_to_list(_("Simulate PSX BIOS"), "HLE");
}
@@ -842,7 +842,7 @@ void OnCpu_Clicked(GtkDialog *dialog, gint arg1, gpointer user_data) {
void OnConf_Cpu() {
GladeXML *xml;
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "CpuDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "CpuDlg", NULL);
if (!xml) {
g_warning("We could not load the interface!");
@@ -671,7 +671,7 @@ void UpdatePluginsBIOS() {
scan_bios_dir(Config.BiosDir);
- // The BIOS list always contains the PCSX internal BIOS
+ // The BIOS list always contains the PCSXR internal BIOS
add_bios_to_list(_("Simulate PSX BIOS"), "HLE");
}
diff --git a/gui/Config.c b/gui/Config.c
index f4b71d81..86038729 100644
--- a/gui/Config.c
+++ b/gui/Config.c
@@ -82,13 +82,13 @@ int LoadConfig(PcsxConfig *Conf) {
// Ryan says: use dotdir, dotdir is GOOD
// No giant homedir names
strncpy(cfgfile, getenv("HOME"), 200);
- strcat(cfgfile, PCSX_DOT_DIR);
+ strcat(cfgfile, PCSXR_DOT_DIR);
// proceed to load the cfg file
// append its name
strcat(cfgfile, cfgfile_basename);
// file is now ~/.pcsx/pcsx.cfg (or whatever cfgfile_basename is)
if (stat(cfgfile, &buf) == -1) {
// the config file doesn't exist!
/* TODO Error checking? */
@@ -82,13 +82,13 @@ int LoadConfig(PcsxConfig *Conf) {
// append its name
strcat(cfgfile, cfgfile_basename);
- // file is now ~/.pcsx/pcsx.cfg (or whatever cfgfile_basename is)
+ // file is now ~/.pcsxr/pcsxr.cfg (or whatever cfgfile_basename is)
if (stat(cfgfile, &buf) == -1) {
// the config file doesn't exist!
diff --git a/gui/Gtk2Gui.c b/gui/Gtk2Gui.c
index 2847f216..4c38d3da 100644
--- a/gui/Gtk2Gui.c
+++ b/gui/Gtk2Gui.c
@@ -213,7 +213,7 @@ void StartGui() {
return;
}*/
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "MainWindow", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "MainWindow", NULL);
if (!xml) {
g_warning("We could not load the interface!");
@@ -221,9 +221,9 @@ void StartGui() {
}
Window = glade_xml_get_widget(xml, "MainWindow");
- gtk_window_set_title(GTK_WINDOW(Window), "PCSX");
- gtk_window_set_icon_from_file(GTK_WINDOW(Window), PIXMAPDIR "pcsx-icon.png", NULL);
- gtk_window_set_default_icon_from_file(PIXMAPDIR "pcsx-icon.png", NULL);
+ gtk_window_set_title(GTK_WINDOW(Window), "PCSXR");
+ gtk_window_set_icon_from_file(GTK_WINDOW(Window), PIXMAPDIR "pcsxr-icon.png", NULL);
+ gtk_window_set_default_icon_from_file(PIXMAPDIR "pcsxr-icon.png", NULL);
ResetMenuSlots(xml);
// Set up callbacks
@@ -363,7 +363,7 @@ void StartGui() {
G_CALLBACK(RunCheatSearchDialog), NULL, NULL, G_CONNECT_AFTER);
// Help menu
- widget = glade_xml_get_widget(xml, "about_pcsx1");
+ widget = glade_xml_get_widget(xml, "about_pcsxr1");
g_signal_connect_data(GTK_OBJECT(widget), "activate",
G_CALLBACK(OnHelp_About), NULL, NULL, G_CONNECT_AFTER);
@@ -786,7 +786,7 @@ void state_load(gchar *state_filename) {
fclose(fp);
// If the window exists, then we are loading the state from within
// within the PCSX GUI. We need to initialise the plugins first
if (Window) {
destroy_main_window();
@@ -786,7 +786,7 @@ void state_load(gchar *state_filename) {
fclose(fp);
// If the window exists, then we are loading the state from within
- // within the PCSX GUI. We need to initialise the plugins first
+ // within the PCSXR GUI. We need to initialise the plugins first
if (Window) {
destroy_main_window();
diff --git a/gui/LnxMain.c b/gui/LnxMain.c
index 8016ea18..4209cbbd 100644
--- a/gui/LnxMain.c
+++ b/gui/LnxMain.c
@@ -78,8 +78,8 @@ static void CreateHomeConfigDir(char *directory) {
}
static void CheckSubDir() {
- // make sure that ~/.pcsx exists
- CreateHomeConfigDir(PCSX_DOT_DIR);
+ // make sure that ~/.pcsxr exists
+ CreateHomeConfigDir(PCSXR_DOT_DIR);
CreateHomeConfigDir(BIOS_DIR);
CreateHomeConfigDir(MEMCARD_DIR);
@@ -109,7 +109,7 @@ static void ScanPlugins(gchar* scandir) {
match(filename, "cfg.*") == 0) {
continue; /* Skip this file */
} else {
/* Create a symlink from this file to the directory ~/.pcsx/plugin */
linkname = g_build_filename (getenv("HOME"), PLUGINS_DIR, ent->d_name, NULL);
symlink(filename, linkname);
@@ -145,7 +145,7 @@ static void ScanBios(gchar* scandir) {
match(filename, ".*\\.BIN$") == 0) {
continue; /* Skip this file */
} else {
/* Create a symlink from this file to the directory ~/.pcsx/plugin */
linkname = g_build_filename(getenv("HOME"), BIOS_DIR, ent->d_name, NULL);
symlink(filename, linkname);
@@ -220,8 +220,8 @@ static void ScanAllPlugins (void) {
ScanBios("/usr/lib32/games/psemu/bios");
ScanBios("/usr/share/psemu");
ScanBios("/usr/share/psemu/bios");
- ScanBios("/usr/share/pcsx");
- ScanBios("/usr/share/pcsx/bios");
+ ScanBios("/usr/share/pcsxr");
+ ScanBios("/usr/share/pcsxr/bios");
ScanBios("/usr/local/lib/games/psemu");
ScanBios("/usr/local/lib/games/psemu/bios");
ScanBios("/usr/local/lib64/games/psemu");
@@ -230,8 +230,8 @@ static void ScanAllPlugins (void) {
ScanBios("/usr/local/lib32/games/psemu/bios");
ScanBios("/usr/local/share/psemu");
ScanBios("/usr/local/share/psemu/bios");
- ScanBios("/usr/local/share/pcsx");
- ScanBios("/usr/local/share/pcsx/bios");
+ ScanBios("/usr/local/share/pcsxr");
+ ScanBios("/usr/local/share/pcsxr/bios");
ScanBios(PACKAGE_DATA_DIR);
ScanBios(PSEMU_DATA_DIR);
ScanBios(PACKAGE_DATA_DIR "/bios");
@@ -245,17 +245,17 @@ static void ScanAllPlugins (void) {
ScanPlugins(currentdir);
g_free(currentdir);
// Check for bad links in ~/.pcsx/plugins/
currentdir = g_build_filename(getenv("HOME"), PLUGINS_DIR, NULL);
CheckSymlinksInPath(currentdir);
g_free(currentdir);
// Check for bad links in ~/.pcsx/plugins/cfg
currentdir = g_build_filename(getenv("HOME"), PLUGINS_CFG_DIR, NULL);
CheckSymlinksInPath(currentdir);
g_free(currentdir);
// Check for bad links in ~/.pcsx/bios
currentdir = g_build_filename(getenv("HOME"), BIOS_DIR, NULL);
CheckSymlinksInPath(currentdir);
g_free(currentdir);
@@ -288,7 +288,7 @@ int main(int argc, char *argv[]) {
// what is the name of the config file?
// it may be redefined by -cfg on the command line
- strcpy(cfgfile_basename, "pcsx.cfg");
+ strcpy(cfgfile_basename, "pcsxr.cfg");
// read command line options
for (i = 1; i < argc; i++) {
@@ -325,12 +325,12 @@ int main(int argc, char *argv[]) {
!strcmp(argv[i], "--help")) {
printf(PACKAGE_STRING "\n");
printf("%s\n", _(
- " pcsx [options] [file]\n"
+ " pcsxr [options] [file]\n"
"\toptions:\n"
"\t-runcd\t\tRuns CD-ROM\n"
"\t-cdfile FILE\tRuns a CD image file\n"
"\t-nogui\t\tDon't open the GTK GUI\n"
- "\t-cfg FILE\tLoads desired configuration file (default: ~/.pcsx/pcsx.cfg)\n"
+ "\t-cfg FILE\tLoads desired configuration file (default: ~/.pcsxr/pcsxr.cfg)\n"
"\t-psxout\t\tEnable PSX output\n"
"\t-slowboot\tEnable BIOS Logo\n"
"\t-load STATENUM\tLoads savestate STATENUM (1-9)\n"
@@ -362,7 +362,7 @@ int main(int argc, char *argv[]) {
// if the config file doesn't exist
if (LoadConfig() == -1) {
if (!UseGui) {
- printf(_("PCSX cannot be configured without using the GUI -- you should restart without -nogui.\n"));
+ printf(_("PCSXR cannot be configured without using the GUI -- you should restart without -nogui.\n"));
return 1;
}
@@ -109,7 +109,7 @@ static void ScanPlugins(gchar* scandir) {
continue; /* Skip this file */
} else {
- /* Create a symlink from this file to the directory ~/.pcsx/plugin */
+ /* Create a symlink from this file to the directory ~/.pcsxr/plugin */
linkname = g_build_filename (getenv("HOME"), PLUGINS_DIR, ent->d_name, NULL);
symlink(filename, linkname);
@@ -145,7 +145,7 @@ static void ScanBios(gchar* scandir) {
continue; /* Skip this file */
} else {
- /* Create a symlink from this file to the directory ~/.pcsx/plugin */
+ /* Create a symlink from this file to the directory ~/.pcsxr/plugin */
linkname = g_build_filename(getenv("HOME"), BIOS_DIR, ent->d_name, NULL);
symlink(filename, linkname);
@@ -245,17 +245,17 @@ static void ScanAllPlugins (void) {
ScanPlugins(currentdir);
g_free(currentdir);
- // Check for bad links in ~/.pcsx/plugins/
+ // Check for bad links in ~/.pcsxr/plugins/
currentdir = g_build_filename(getenv("HOME"), PLUGINS_DIR, NULL);
CheckSymlinksInPath(currentdir);
@@ -245,17 +245,17 @@ static void ScanAllPlugins (void) {
CheckSymlinksInPath(currentdir);
g_free(currentdir);
- // Check for bad links in ~/.pcsx/plugins/cfg
+ // Check for bad links in ~/.pcsxr/plugins/cfg
currentdir = g_build_filename(getenv("HOME"), PLUGINS_CFG_DIR, NULL);
CheckSymlinksInPath(currentdir);
@@ -245,17 +245,17 @@ static void ScanAllPlugins (void) {
CheckSymlinksInPath(currentdir);
g_free(currentdir);
- // Check for bad links in ~/.pcsx/bios
+ // Check for bad links in ~/.pcsxr/bios
currentdir = g_build_filename(getenv("HOME"), BIOS_DIR, NULL);
CheckSymlinksInPath(currentdir);
diff --git a/gui/MemcardDlg.c b/gui/MemcardDlg.c
index f799f76f..6f8f3404 100644
--- a/gui/MemcardDlg.c
+++ b/gui/MemcardDlg.c
@@ -433,8 +433,8 @@ static void OnMcd_New(GtkWidget *widget, gpointer user_data) {
GTK_STOCK_SAVE, GTK_RESPONSE_OK,
NULL);
- // Card should be put into $HOME/.pcsx/memcards
- path = g_build_filename(g_get_home_dir(), ".pcsx", "memcards", NULL);
+ // Card should be put into $HOME/.pcsxr/memcards
+ path = g_build_filename(g_get_home_dir(), ".pcsxr", "memcards", NULL);
gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(chooser), path);
gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(chooser), _("New Memory Card.mcd"));
gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(chooser), TRUE);
@@ -692,7 +692,7 @@ void OnConf_Mcds() {
GtkTreeSelection *treesel1, *treesel2;
gchar *str;
- xml = glade_xml_new(PACKAGE_DATA_DIR "pcsx.glade2", "McdsDlg", NULL);
+ xml = glade_xml_new(PACKAGE_DATA_DIR "pcsxr.glade2", "McdsDlg", NULL);
if (!xml) {
g_warning("We could not load the interface!");